

set -ex



test -f "${PREFIX}/include/CL/cl.h"
test -f "${PREFIX}/lib/libOpenCL.so.1"
test -d "${PREFIX}/etc/OpenCL/vendors"
$CC -o test ocl_test.c -L${PREFIX}/lib -lOpenCL -I${PREFIX}/include
./test
./test | grep "No platforms found!"
exit 0
